@@ -359,7 +359,7 @@ lmer <- function(formula, data, family = gaussian,
     ## FIXME: change this when rbind has been fixed.
     Zt <- if (length(Ztl) == 1) Ztl[[1]] else do.call("rbind", Ztl)
     fl <- FL$fl
-    
+
     ## check and evaluate the family argument
     if(is.character(family))
         family <- get(family, mode = "function", envir = parent.frame())
@@ -371,7 +371,7 @@ lmer <- function(formula, data, family = gaussian,
     fltype <- mkFltype(family)
     if (fltype == 1) fltype <- 0
     method <- match.arg(method)
-    
+
     ## quick return for a linear mixed model
     if (fltype < 0) {
         mer <- .Call(mer_create, fl, Zt, X, Y, method == "REML", nc, cnames)
@@ -389,7 +389,7 @@ lmer <- function(formula, data, family = gaussian,
     if (method == "AGQ")
         stop('method = "AGQ" not yet implemented for supernodal representation')
     if (method == "PQL") cv$usePQL <- TRUE # have to use PQL for method == "PQL"
-    
+
     ## initial fit of a glm to the fixed-effects only.
     glmFit <- glm.fit(X, Y, weights = weights, offset = offset, family = family,
                       intercept = attr(mt, "intercept") > 0)
@@ -442,11 +442,14 @@ lmer <- function(formula, data, family = gaussian,
                              function(k) 1:((k*(k+1))/2) <= k)
                       ))
     devLaplace <- function(pars) .Call(glmer_devLaplace, pars, GSpt)
+    rel.tol <- abs(0.01/devLaplace(PQLpars))
+    cat(paste("relative tolerance set to", rel.tol, "\n"))
 
     optimRes <- nlminb(PQLpars, devLaplace,
                        lower = ifelse(const, 5e-10, -Inf),
                        control = list(trace = cv$msVerbose,
-                       iter.max = cv$msMaxIter))
+                       iter.max = cv$msMaxIter,
+                       rel.tol = rel.tol))
     .Call(glmer_finalize, GSpt)
     new("glmer",
         new("lmer", mer,
@@ -679,10 +682,8 @@ setMethod("simulate", signature(object = "mer"),
 	      on.exit(assign(".Random.seed", R.seed, envir = .GlobalEnv))
 	  }
 
-	  family <- object@family
-	  if (family$family != "gaussian" ||
-	      family$link != "identity")
-	      stop("simulation of generalized linear mixed models not yet implemented")
+          stopifnot((nsim <- as.integer(nsim[1])) > 0,
+                    inherits(object, "lmer"))
 	  ## similate the linear predictors
 	  lpred <- .Call(mer_simulate, object, nsim)
 	  sc <- abs(object@devComp[8])
@@ -695,13 +696,14 @@ setMethod("simulate", signature(object = "mer"),
 	  lpred
       })
 
+### "FIXME": the following has too(?) much cut & paste from above
+
 simulestimate <- function(x, FUN, nsim = 1, seed = NULL, control = list())
 {
     FUN <- match.fun(FUN)
-    nsim <- as.integer(nsim[1])
-    stopifnot(nsim > 0)
+    stopifnot((nsim <- as.integer(nsim[1])) > 0,
+	      inherits(x, "lmer"))
     if (!is.null(seed)) set.seed(seed)
-    stopifnot(inherits(x, "lmer"))
     ## similate the linear predictors
     lpred <- .Call(mer_simulate, x, nsim)
     sc <- abs(x@devComp[8])
@@ -1186,108 +1188,3 @@ hatTrace <- function(x)
     .Call(mer_hat_trace2, x)
 }
 
-mlirt <-
-    function(formula, data, family = binomial("probit"),
-             control = list(), start = NULL,
-             subset, weights, na.action = na.pass, offset,
-             contrasts = NULL, model = FALSE, ...)
-{
-    formula <- as.formula(formula)
-    if (length(formula) < 3) stop("formula must be a two-sided formula")
-    cv <- do.call("lmerControl", control)
-
-    ## Should difficulties be modeled as random effects?
-
-    ranDiff <- ".item" %in% all.vars(formula)
-    ## Establish model frame and fixed-effects model matrix and terms
-    mc <- match.call()
-    fr <- lmerFrames(mc, formula, data, contrasts)
-    Y <- fr$Y
-
-    ## check for a binary matrix response
-    if (!is.matrix(Y) || !is.numeric(Y) ||
-        any(!(unique(as.vector(Y)) %in% c(0, 1, NA)))) 
-        stop("Response must be a binary, numeric matrix")
-    nr <- nrow(Y)
-    nc <- ncol(Y)
-    ## expand model frame etc according to the items
-    ind <- rep.int(1:nr, nc)
-    mf <- fr$mf[ind, ]
-    X <- fr$X[ind, ]
-    if (ranDiff) mf$.item <- gl(nc, nr)
-    else X <- cbind(X, -contr.sum(nc)[rep(1:nc,each = nr),])
-    Y <- as.vector(Y)
-    offset <- fr$offset[ind]
-
-    mf$.subj <- gl(nr, 1, nr*nc)
-    form <- substitute(Y ~ base + (1|.subj), list(base = formula[[3]])) 
-    ## establish factor list and Ztl
-    FL <- lmerFactorList(form, mf)
-    cnames <- with(FL, c(lapply(Ztl, rownames), list(.fixed = colnames(X))))
-    nc <- with(FL, sapply(Ztl, nrow))
-    Ztl <- with(FL, .Call(Ztl_sparse, fl, Ztl))
-    ## FIXME: change this when rbind has been fixed.
-    Zt <- if (length(Ztl) == 1) Ztl[[1]] else do.call("rbind", Ztl)
-    fl <- FL$fl
-
-    ## check and evaluate the family argument
-    if(is.character(family))
-        family <- get(family, mode = "function", envir = parent.frame())
-    if(is.function(family)) family <- family()
-    if(is.null(family$family)) {
-        print(family)
-        stop("'family' not recognized")
-    }
-    if (family$family != "binomial")
-        stop("family must be a binomial family")
-    fltype <- mkFltype(family)
-
-    ## initial fit of a glm to the fixed-effects only.
-    glmFit <- glm.fit(X, Y, weights = fl$weights[ind],
-                      offset = offset, family = family,
-                      intercept = attr(fr$mt, "intercept") > 0)
-    Y <- as.double(glmFit$y)
-    ## must do this after Y has possibly been reformulated
-    mer <- .Call(mer_create, fl, Zt, X, Y, 0, nc, cnames)
-    if (!is.null(start)) mer <- setOmega(mer, start)
-
-    gVerb <- getOption("verbose")
-
-    ## extract some of the components of glmFit
-    ## weights could have changed
-    weights <- glmFit$prior.weights
-    eta <- glmFit$linear.predictors
-    linkinv <- quote(family$linkinv(eta))
-    mu.eta <- quote(family$mu.eta(eta))
-    mu <- family$linkinv(eta)
-    variance <- quote(family$variance(mu))
-    dev.resids <- quote(family$dev.resids(Y, mu, weights))
-    doLMEopt <- quote(LMEopt(x = mer, value = cv))
-    mer@devComp[8] <- -mean(weights)
-    mer@status["glmm"] <- as.integer(2) # always use Laplace
-    GSpt <- .Call(glmer_init, environment(), fltype)
-    PQLpars <- c(coef(glmFit), .Call(mer_coef, mer, 2))
-    fixInd <- seq(ncol(X))
-    ## pars[fixInd] == beta, pars[-fixInd] == theta
-    ## indicator of constrained parameters
-    const <- c(rep(FALSE, length(fixInd)),
-               unlist(lapply(mer@nc[seq(along = fl)],
-                             function(k) 1:((k*(k+1))/2) <= k)
-                      ))
-    devLaplace <- function(pars) .Call(glmer_devLaplace, pars, GSpt)
-    rel.tol <- abs(0.01/devLaplace(PQLpars))
-    cat(paste("relative tolerance set to", rel.tol, "\n"))
-
-    optimRes <- nlminb(PQLpars, devLaplace,
-                       lower = ifelse(const, 5e-10, -Inf),
-                       control = list(trace = cv$msVerbose,
-                       iter.max = cv$msMaxIter,
-                       rel.tol = rel.tol))
-    .Call(glmer_finalize, GSpt)
-    new("glmer",
-        new("lmer", mer,
-            frame =  data.frame(),
-            terms = fr$mt, call = match.call()),
-        weights = weights,
-        family=family)
-}
